---
title: "Obsidian October 2025"
author: "kepano"
site: "r/ObsidianMD"
source: "https://www.reddit.com/r/ObsidianMD/comments/1nvmgpp/obsidian_october_2025/"
language: "en-US"
word_count: 396
---

Obsidian October is back! Every October, the community comes together to hack on plugins, themes, vaults, videos, and other projects. We’ll host office hours on [Discord](https://discord.gg/obsidianmd) to help you polish your creations, ship updates, or kick off that project you’ve been itching to build!

**Polish and release**

If you don’t know where to start, take a look at our self-assessment checklists. We’ve updated these checklists with the latest requirements and recommendations to make your plugins and themes more performant, more secure, more mobile-friendly, and more cohesive with Obsidian.

- [Plugin checklist](https://docs.obsidian.md/oo/plugin)
- [Theme checklist](https://docs.obsidian.md/oo/theme)
- [Vault checklist](https://docs.obsidian.md/oo/vault)

**Try something new with Bases**

Recently we launched [Obsidian 1.9](https://obsidian.md/changelog/2025-08-18-desktop-v1.9.10/) with [Bases](https://help.obsidian.md/bases), a new core plugin that lets you display dynamic views of your notes as tables, cards, and now lists.

Today, we’re releasing [Obsidian 1.10 beta](https://obsidian.md/changelog/2025-10-01-desktop-v1.10.0/) with Bases APIs to help you create your own custom view layouts. As an example, we’ve created a new open source plugin called [Maps](https://github.com/obsidianmd/obsidian-maps) that adds map views to Bases.

Bases can be a playground for new kinds of workflows, templates, and vaults. Educational content can help other Obsidian users discover the power of Bases. Want some feedback on your blog post or video? This is the time for it!

**Join the fun**

Now’s the time to share your Obsidian October projects and get feedback from the Obsidian team and other participants! Join our new Discord channels to [showcase your project](https://discord.com/channels/686053708261228577/1422625327959642252) and [chat with other participants](https://discord.com/channels/686053708261228577/1422624480534073434).

